@@ -11,9 +11,14 @@ import unittest
 
 from couchdbkit import *
 
+
+from restkit import SimplePool
+pool = SimplePool()
+
+
 class DocumentTestCase(unittest.TestCase):
     def setUp(self):
-        self.server = Server()
+        self.server = Server(pool_instance=pool)
 
     def tearDown(self):
         try:
@@ -478,11 +483,11 @@ class DocumentTestCase(unittest.TestCase):
         a.save()
         
         text_attachment = "un texte attaché"
-        old_rev = a._rev
         
         a.put_attachment(text_attachment, "test", "text/plain")
         a.delete_attachment('test')
         self.assertRaises(ResourceNotFound, a.fetch_attachment, 'test')
+        self.assertFalse('test' in a._doc['_attachments'])
         
         self.server.delete_db('couchdbkit_test')
 
@@ -510,7 +515,7 @@ class DocumentTestCase(unittest.TestCase):
 class PropertyTestCase(unittest.TestCase):
 
     def setUp(self):
-        self.server = Server()
+        self.server = Server(pool_instance=pool)
         try:
             self.db = self.server.create_db('couchdbkit_test')
         except: 
